*TTULO DE LA SINTAXIS:													   
* Indicadores ODS agua y saneamiento - ENEMDU									
* OPERACIN ESTADSTICA:													   
* Encuesta Nacional de Empleo, Desempleo y Subempleo (ENEMDU)		   		   
* UNIDAD TCNICA RESPONSABLE: 												   
* Direccin de Innovacin en Mtricas y Metodologas (DINME)			   	   
* ENTIDAD EJECUTORA:														   
* Instituto Nacional de Estadstica y Censos (INEC)							   
*===================================================================================*
* Fecha de elaboracin:        						   						
* Fecha de elaboracin:        05 de octubre del 2016						
* Fecha ltima modificacin:   12 de mayo del 2017						
*===================================================================================*
* Elaborado por:															   
* Juan Carlos Serrano																  
* Analista de DINME															  
* Instituto Nacional de Estadstica y Censos (INEC)							   
* juan_serrano@inec.gob.ec													   
* Mnica Pozo															   
* Analista de DINME															   
* Instituto Nacional de Estadstica y Censos (INEC)							   
* monica_pozo@inec.gob.ec
* Revisado por:
* Lorena Moreno
* lorena_moreno@inec.gob.ec
* Instituto Nacional de Estadstica y Censos (INEC)							   										   
*===================================================================================*

clear all
set more off

/*cd  =INCLUIR DIRECTORIO==*/
cd "........"

use ".......", clear


*Set de la base
*INDICADORES A NIVEL DE HOGAR
svyset id_sector [iw = fexp2], strata(plan_muestreo) vce(linearized) singleunit(certainty)

/*INDICADORES A NIVEL DE PERSONA
*Nota: Para calcular los indicadores a nivel de persona se debe correr esta parte de la sintaxis
que se encuentra comentada*/

*gen fexper = fexp2 * numper
*svyset id_sector [iw = fexper], strata(plan_muestreo) vce(linearized) singleunit(certainty)

/*================================================================================================
* Indicator 6.1.1 "Porcentaje de los hogares que utilizan suministros seguros de agua para beber"
*=================================================================================================

* Componentes del indicador: 1) tipo de suministro
							 2) calidad del agua
							 3) cercana del suministro
							 4) suficiencia de agua para beber */
							 
* 1. Tipo de suministro
recode vi16 (1/3   =1 "tuberia")(4/7   =2 "Otro"), gen(vi16r)

recode vi17 (1/3 7 9    = 1 "tipo A") ///
            (4 8 10 12  = 2 "tipo B") ///
			(11 13      = 3 "tipo C"), gen(agua_cp1) 
label var agua_cp1 "tipo de suministro"	
replace agua_cp1 = 1 if inlist(vi17,5,6) & vi16r==1
replace agua_cp1 = 2 if inlist(vi17,5,6) & vi16r==2

/* 2. Calidad del agua -libre de contaminacin fecal (bacteria ecoli)
 regs04 : Horas de incubacin - entre 20 y 48 horas
 regsp01 : La muestra de agua tiene coloracin amarilla?
 regsp02 : La muestra se hizo fluorescente al exponerse a la luz uv?
 regsp03: Hubo una prdida de ms del 10 % (10ml) del contenido de la muestra de agua?
 regsp04: Estuvo la muestra expuesta a temperaturas menores a 30 o mayores a 40 por ms de 4 horas? */

	* Se identifican pruebas vlidas
	gen     validtest = 0 if vi20a==1 
	replace validtest = 1 if vi20a==1 & (regs04 >=20 & regs04<=48) & regsp03==2 & regsp04==2
	replace validtest = 2 if vi20a==2 
	
    label def validtest 0 "no" 1 "si" 2 "rechazo", replace
	label val validtest validtest
	label var validtest "Prueba vlida?"
		
	* Presencia de coliformes
	gen      coli =0 if validtest==1
	replace  coli =1 if validtest==1 & regsp01==1
	replace  coli =2 if validtest==1 & regsp01==2
	label def coli 1 "si" 2 "no", replace
	label val coli coli
	label var coli "presencia de coliformes"
		
	* Ausencia de Ecoli
	gen     agua_cp2 =0 if validtest==1 
	replace agua_cp2 =1 if validtest==1 & regsp02==2
	replace agua_cp2 =2 if validtest==1 & regsp02==1
	label def agua_cp2 1 "si" 2 "no", replace
	label val agua_cp2 agua_cp2
	label var agua_cp2 "calidad del agua"

* 3. Cercana del suministro
gen     agua_cp3 = 0 
replace agua_cp3 = 1 if inlist(vi17a,1,2) 
replace agua_cp3 = 1 if inlist(vi17,5,6)
* Nota.- el supuesto es que el agua embotellada est cerca para el consumo
replace agua_cp3 = 2 if vi17a==3 & vi17b <=30
replace agua_cp3 = 3 if vi17a==3 & vi17b > 30 // incluye la categora no sabe 999

* Se  encuentra fuera de la vivienda, edifico/lote y no sabe a cuanto se encuentra (en minutos) la fuente 
replace agua_cp3 = . if vi17b==999 & (vi17a!=1 | vi17a!=2) 

lab def agua_cp3 ///
1 "terreno/edificio" ///
2 "menos o igual a 30 min" ///
3 "ms de 30 min", replace
label values agua_cp3 agua_cp3
label var agua_cp3 "cercana del suministro"

* 4. Suficiencia de agua para beber
gen     agua_cp4 = 0
replace agua_cp4 = 1 if vi17c==1
replace agua_cp4 = 2 if vi17c >1
replace agua_cp4 = . if vi17c==3
label def agua_cp4 1 "continuo" 2 "no continuo", replace
label val agua_cp4 agua_cp4
label var agua_cp4 "continuidad del suministro"

*====================================================================================

gen i_agua = 0 if !mi(agua_cp1) & !mi(agua_cp2) & !mi(agua_cp3) & !mi(agua_cp4) 

* manejo seguro
replace i_agua = 1 if agua_cp1==1 & agua_cp2==1 & agua_cp3==1 & agua_cp4==1
* bsico 1
replace i_agua = 2 if agua_cp1==1 & agua_cp2==1 & agua_cp3==1 & agua_cp4==2 /**/
replace i_agua = 2 if agua_cp1==1 & agua_cp2==1 & agua_cp3==2 /**/
* bsico 2
replace i_agua = 3 if agua_cp1==1 & agua_cp2==2 & agua_cp3==1 /**/
replace i_agua = 3 if agua_cp1==1 & agua_cp2==2 & agua_cp3==2 /**/
* limitado
replace i_agua = 4 if agua_cp1==1 				& agua_cp3==3 
* no mejorado
replace i_agua = 5 if agua_cp1==2
* superficial
replace i_agua = 6 if agua_cp1==3

label def i_agua ///
1 "seguro" ///
2 "bsico 1" ///
3 "bsico 2" ///
4 "limitado" ///
5 "no mejorado" ///
6 "superficial", replace
label values i_agua i_agua
label var i_agua "Servicios de agua para beber manejado de forma segura"


/*===================================================================================
* Indicator 6.2.1: "Porcentaje de la poblacin que usa servicios de saneamiento 
manejados de forma segura"
*====================================================================================

* Componentes del indicador: 1) tipo de sistema de saneamiento
							 2) exclusividad del servicio,
							 3) manejo de desechos */

* 1.tipo de sistema de saneamiento

gen sanea_cp1 = 0
* Excusado y alcantarillado: 
replace sanea_cp1 =1 if vi13==1
* Excusado y pozo sptico:
replace sanea_cp1 =2 if vi13==2
* Excusado y pozo ciego: 
replace sanea_cp1 =3 if vi13==3 
* Letrina con losa:
replace sanea_cp1 =4 if vi13==4 & vi13b==1
* Letrina sin losa
replace sanea_cp1 =5 if vi13==4 & vi13b==2
* Prestado 1 - alcantarillado, pozo sptico, pozo ciego
replace sanea_cp1 =6 if vi13==5 & vi13d==2 & inrange(vi14,1,3)
* Prestado 2 - letrina
replace sanea_cp1 =7 if vi13==5 & vi13d==2 & vi14==4
* No tiene 
replace sanea_cp1 =8 if vi13==5 & vi13d==1

lab def sanea_cp1 ///
1 "Alcantarillado" ///
2 "Pozo sptico" ///
3 "Pozo ciego" ///
4 "Letrina con losa" ///
5 "Letrina sin losa" ///
6 "Prestado 1" ///
7 "Prestado 2" ///
8 "No tiene", replace 
label values sanea_cp1 sanea_cp1

* 2. exclusividad del servicio
gen sanea_cp2 =0
replace sanea_cp2 =1 if vi15==2
replace sanea_cp2 =2 if vi15==1 | vi13==5
lab def compartir ///
1 "exclusivo" ///
2 "compartido", replace
label values sanea_cp2 sanea_cp2
label var sanea_cp2 "uso del servicio"	

* 3. Manejo de excretas
gen sanea_cp3 =0
* Excusado y alcantarillado: 
replace sanea_cp3 =2 if vi13==1
 /* Nota.- No es posible estimar directamente. Por lo que no se puede clasificar 
 como manejo seguro*/
   
* Excusado y pozo sptico / ciego:
replace sanea_cp3 =1 if inlist(vi13,2,3) & inlist(vi13a,2,3,4) & vi13c==2
replace sanea_cp3 =2 if inlist(vi13,2,3) & inlist(vi13a,2,3,4) & vi13c==1
replace sanea_cp3 =2 if inlist(vi13,2,3) & vi13a ==1
* Letrina con losa y sin losa:
replace sanea_cp3 =1 if vi13==4 & vi13c==2
*replace sanea_cp3 =2 if vi13==4 & inlist(vi13c,1,3)
replace sanea_cp3 =2 if vi13==4 & vi13c==1
*Missing si responde "no sabe" en 13c dependiendo de la condicin
replace sanea_cp3 =. if inlist(vi13,2,3) & inlist(vi13a,2,3,4) & vi13c==3
replace sanea_cp3 =. if vi13==4 & vi13b==1 & vi13c==3
 
lab def sanea_cp3 ///
1 "seguro" ///
2 "no seguro", replace
label values sanea_cp3 sanea_cp3
label var sanea_cp3 "manejo de excretas"       
 
*====================================================================================

gen i_sanea = 0 if !mi(sanea_cp1) & !mi(sanea_cp2) & !mi(sanea_cp3)

* bsico
replace i_sanea = 1 if inrange(sanea_cp1,1,4) & sanea_cp2==1 & sanea_cp3==1
replace i_sanea = 1 if inrange(sanea_cp1,1,4) & sanea_cp2==1 & sanea_cp3==2
* limitado
replace i_sanea = 2 if inlist(sanea_cp1,1,4)  & sanea_cp2==2 
replace i_sanea = 2 if inlist(sanea_cp1,2,3)  & sanea_cp2==2 & sanea_cp3==1
replace i_sanea = 2 if sanea_cp1==6
* no mejorado
replace i_sanea = 3 if inrange(sanea_cp1,2,4) & sanea_cp2==2 & sanea_cp3==2
replace i_sanea = 3 if inlist(sanea_cp1,5,7)
* al aire libre
replace i_sanea = 4 if sanea_cp1==8
 
lab def i_sanea ///
1 "bsico" ///
2 "limitado" ///
3 "no mejorado" ///
4 "al aire libre", replace
label values i_sanea i_sanea
label var i_sanea "servicios de saneamiento - ODS"    

/*=============================================================================================
* Indicator 6.2.2: "Porcentaje de la poblacin que dispone de una istalacin 
para lavarse las manos con agua y jabn"
*============================================================================================= */

* 1.Instalacin
gen higiene_cp1=0
replace higiene_cp1 = 1 if vi21==1
replace higiene_cp1 = 2 if vi21==2 & inlist(vi24,1,3)
*No permite la observacin
replace higiene_cp1 = . if vi21==2 & vi24==2
*otras razones
replace higiene_cp1 = . if vi21==2 & vi24==4

lab def higiene_cp1 ///
1 "Con instalacin" ///
2 "Sin instalacin", replace
lab values higiene_cp1 higiene_cp1
label var higiene_cp1 "Instalacin para lavarse las manos"	

* 2.Agua
gen higiene_cp2=0
replace higiene_cp2 = 1 if vi21==1 & vi22==1
replace higiene_cp2 = 2 if vi21==1 & vi22==2
replace higiene_cp2 = . if vi21==2 

lab def higiene_cp2 ///
1 "Si tiene agua" ///
2 "No tiene agua", replace
lab values higiene_cp2 higiene_cp2
label var higiene_cp2 "Agua para lavarse las manos"

* 3.Jabn
gen higiene_cp3=0
replace higiene_cp3 = 1 if vi21==1 & ((vi23a==1 | vi23b==1) & (vi23e==2))
replace higiene_cp3 = 2 if vi21==1 & (vi23a!=1 & vi23b!=1)
replace higiene_cp3 = . if vi21==2 

lab def higiene_cp3 ///
1 "Si tiene jabn" ///
2 "No tiene jabn", replace
lab values higiene_cp3 higiene_cp3
label var higiene_cp3 "Jabon para lavarse las manos"

*====================================================================================

gen i_higiene = 0 if  !mi(higiene_cp1) | !mi(higiene_cp2) | !mi(higiene_cp3)

*bsico
replace i_higiene = 1 if higiene_cp1==1 & higiene_cp2==1 & higiene_cp3==1

*limitado
replace i_higiene = 2 if higiene_cp1==1 & higiene_cp2==1 & higiene_cp3==2
replace i_higiene = 2 if higiene_cp1==1 & higiene_cp2==2 & higiene_cp3==1
replace i_higiene = 2 if higiene_cp1==1 & higiene_cp2==2 & higiene_cp3==2

*sin instalacin
replace i_higiene = 3 if higiene_cp1==2

lab def i_higiene ///
1 "basico" ///
2 "limitado" ///
3 "sin instalacin", replace
lab values i_higiene i_higiene
label var i_higiene "presencia de agua y jabon - ODS"


*====================================================================================

*====================================================================================
* FIN 
*====================================================================================
