*==============================================================================*
* TTULO DE LA SINTAXIS:													   *

* Plan de tabulados Indicadores Agua y Saneamiento - ENEMDU					   *
* OPERACIN ESTADSTICA:													   *
* Encuesta Nacional de Empleo, Desempleo y Subempleo (ENEMDU)		   		   *
* UNIDAD TCNICA RESPONSABLE: 												   *
* Direccin de Innovacin en Mtricas y Metodologas (DINME)			   	   *
* ENTIDAD EJECUTORA:														   *
* Instituto Nacional de Estadstica y Censos (INEC)							   *
*==============================================================================*
* Fecha de elaboracin:        27 de marzo del 2017							   *
* Fecha ltima modificacin:   15 de mayo del 2017							   *
*==============================================================================*
* Elaborado por:															   *
* Juan Carlos Serrano														   *
* Analsta de DINME															   *
* Instituto Nacional de Estadstica y Censos (INEC)							   *
* juan_serrano@inec.gob.ec							     					   *
* Mnica Pozo   															   *
* Analsta de DINME															   *
* Instituto Nacional de Estadstica y Censos (INEC)							   *
* monica_pozo@inec.gob.ec													   *
* Revisado por:																   *
* Lorena Moreno 			
* lorena_moreno@inec.gob.ec												   *
* Instituto Nacional de Estadstica y Censos (INEC)							   *   										   
*==============================================================================*

												   *
*==============================================================================*

clear all
set more off
set matsize 11000

*==============================================================================*
*								MODIFICAR									   *
*==============================================================================*

// Directorio
cd "......"

*Construccin indicadores ODS - Sintaxis
/*NOTA: La sintaxis para construir los indicadores ODS debe colocarse en
la carpeta del directorio*/

*Incluir la sintaxis de los ODS

include "....."

*Etnia del jefe de hogar
** Auto-identificacin tnica **
 
recode p15 (1 = 1 "Indgena") (2/4 = 2 "Afrodescendiente") (5 = 3 "Montubio") ///
(6 = 4 "Mestizo") (7 = 5 "Blanco") (8 = 6 "Otro"), gen(etnia) label(etnia)

gen aux_etnia_jefe = etnia if p04==1
bys id_hogar: egen etnia_jefe = max(aux_etnia_jefe)
label var etnia_jefe "Etnia del jefe de hogar"

*Nivel instruccin jefe de hogar
gen nivi_ns=.
replace nivi_ns=1 if p10a==1
replace nivi_ns=2 if p10a==2
replace nivi_ns=3 if p10a==3
replace nivi_ns=3 if p10a==4
replace nivi_ns=3 if p10a==5
replace nivi_ns=3 if p10a==6 & p10b<=3
replace nivi_ns=4 if p10a==6 & p10b>=4
replace nivi_ns=4 if p10a==7
replace nivi_ns=5 if inrange(p10a,8,10)
 
# delimit;
label define nivi_ns 
1"Ninguno"
2"Centro de alfabetizacin"
3"Bsica"
4"Bachillerato"
5"Superior";
# delimit cr
 
label value nivi_ns nivi_ns

gen aux_ninst_jefe = nivi_ns if p04==1
bys id_hogar: egen ninst_jefe = max(aux_ninst_jefe)
label var ninst_jefe "Nivel de instruccin del jefe de hogar"

*Quintil
xtile quintil= ingpc [pw=fexp2], n(5)
				
*Condicin de la vivienda
* Material y condicin del techo
# delimit ;	
    gen techo=1 if
	((vi03a==1 & inrange(vi03b,1,2))	
	|(vi03b==1 & inrange(vi03a,2,4)))	
	;	
	replace techo=2 if
	((vi03a==1 & vi03b==3)
	| vi03b==2 & inrange(vi03a,2,4))
	;	
	replace techo=3 if
	((vi03b==3 & inrange(vi03a,2,4))
	|(vi03a==5 | vi03a==6))
	;
    # delimit cr
	 
* Material y condicin de las paredes
	# delimit ;
	gen pared=1 if 
	((vi05a==1 & inrange(vi05b,1,2))
	|(vi05a==2 & vi05b==1))
	;
	replace pared=2 if
	((vi05a==1 & vi05b==3)
	|(vi05a==2 & vi05b==2)
	|(inrange(vi05a,3,5) & inrange(vi05b,1,2))) 
	;
	replace pared=3 if
	 ((vi05b==3 & inrange(vi05a,2,5))
	|(vi05a==6 | vi05a==7))     
	;
    # delimit cr
	
* Material y condicin del piso
	# delimit ;
	gen     piso=1 if
	((vi04a<=3 & vi04b==1)
	|(vi04a<=3 & vi04b==2)
	|(vi04b==1 & inrange(vi04a,4,5)))	
	;
    replace piso=2 if
	((vi04a <= 3 & vi04b == 3)
	|(vi04b==2 & inrange(vi04a,4,5))	
	|(vi04a==6 & vi04b==1))
	;
	replace piso=3 if
	((vi04b==3 & inlist(vi04a,4,5,6))
	|(vi04a==6 & vi04b==2)
	|(vi04a==7 | vi04a==8))
	;
	# delimit cr
		
* Tipologa de Vivienda
	# delimit ;
	gen     tipviv=1 if
	(techo==1 & pared==1 & piso==1)
	|(techo==1 & pared==1 & piso==2)
	|(techo==1 & pared==2 & piso==1)
	;
	replace tipviv=2 if
	(techo==1 & pared==1 & piso==3)
	|(techo==1 & pared==2 & inrange(piso,2,3))
	| techo==1 & pared==3 & inrange(piso,1,2)
    | techo==2 & pared==1 & inrange(piso,1,2)
	| techo==2 & pared==2 & inrange(piso,1,2)
	| techo==3 & pared==1 & inrange(piso,1,2)
	|(techo==3 & pared==2 & piso==1)
	;
	replace tipviv=3 if	
	(techo==1 & pared==3 & piso==3)
	|(techo==2 & pared==1 & piso==3)
	|(techo==2 & pared==2 & piso==3)
	| techo==2 & pared==3 & inrange(piso,1,3)
	|(techo==3 & pared==1 & piso==3)
	| techo==3 & pared==2 & inlist(piso,2,3)
	|(techo==3 & pared==3 & inrange(piso,1,3))
	;
	# delimit cr
		
label define tipviv 1 "Aceptables" 2 "Recuperables" 3 "Irrecuperables"
label values tipviv tipviv
		
*Hacinamiento
recode vi07 (0=1)
gen 	hacina=1 if (numper/vi07)> 3
replace hacina=0	if (numper/vi07)<=3
label define hacina 0 "No Hacinada" 1 "Hacinada"
label values hacina hacina
label var hacina "Personas en Condicin de Hacinamiento"

recode sanea_cp1 (1/4 = 1 "Mejorado") (5/8 = 2 "No mejorado"), gen (sanea_cp1n)

	
****************
***TABULADOS****
****************

forvalues j= 1/3{
/*Tablas*/

local variables = "i_sanea sanea_cp1n sanea_cp2 sanea_cp3 i_higiene higiene_cp1 higiene_cp2 higiene_cp3 i_agua agua_cp1 agua_cp2 agua_cp3 agua_cp4"


if `j'==1 {
local iden ="Nacional"
preserve
}
 
if `j'==2 {

local iden ="Nopobre"
preserve
keep if pobre==0
}

if `j'==3 {

local iden ="Pobres"
preserve
keep if pobre==1
}


levelsof area, local(niv)
di "`niv'"
local name1=" "
local name=" "
foreach nivel of local niv {
		
	local etiq1: label (area) `nivel'
	local etiq1= strtoname("`etiq1'",0)
	local etiq2= "`=strtoname("`etiq1'",0)'_%" 
	local etiq3= "`=strtoname("`etiq1'",0)'_cv"
	local etiq4= "`=strtoname("`etiq1'",0)'_N"
	local etiq5= "`=strtoname("`etiq1'",0)'_Npop"
	local etiq6= "`=strtoname("`etiq1'",0)'_deff"
	# delimit;
	
	local name1=  "`name1' "+"`nivel'_`etiq1' `nivel'_`etiq3' 
	`nivel'_`etiq4' `nivel'_`etiq5' _`nivel'_`etiq6'
	`nivel'_`etiq2' `nivel'_`etiq3'  
	`nivel'_`etiq4' `nivel'_`etiq5' `nivel'_`etiq6'"
	;
	#delimit cr

	}
di in red "`name1'"

foreach var of local variables {
tab `var', gen(dumm_`var')
levelsof `var', local(niv1)
di in red "`niv1'"

levelsof area, local(niv)
di "`niv'"

local n=1

foreach i of local niv1 {
	local etiq: label (`var') `i'
	local etiq= substr(strtoname("`etiq'",0),1,20)
	local name= "`name' "+"`var'_`i'_`etiq'"
di "`name'"


	svy: total dumm_`var'`n'
	estat cv
	mat aux=e(b), r(cv),e(N), e(N_pop)
	estat effects
	mat aux=aux, r(deff)
	mat T_`var'=nullmat(T_`var')\aux

	
	svy: mean dumm_`var'`n'
	estat cv
	mat aux=e(b),r(cv),e(N),e(N_pop)
	estat effects
	mat aux=aux, r(deff)
	mat P_`var'=nullmat(P_`var')\aux
	mat N_`var' = T_`var', P_`var'
	
		foreach nivel of local niv {
		svy: total dumm_`var'`n' if area==`nivel'
		estat cv
		mat aux=e(b), r(cv),e(N),e(N_pop)
	    estat effects 
		mat aux=aux,r(deff)
		mat T_`var'_`nivel'=nullmat(T_`var'_`nivel')\aux
		svy: mean dumm_`var'`n' if area==`nivel'
		estat cv
		mat aux=e(b), r(cv),e(N),e(N_pop)
		estat effects
		mat aux=aux, r(deff)
		mat P_`var'_`nivel'=nullmat(P_`var'_`nivel')\aux
		mat S_`var'_`nivel'= T_`var'_`nivel',P_`var'_`nivel'
		
}
local ++n
}


mat final`iden' = nullmat(final`iden')\N_`var',S_`var'_1,S_`var'_2 
mat rowname final`iden' = `name'



#delimit
mat colname final`iden' = nacional nacional_cv nacional_N nacional_Npop nacional_deff
nacional_% nacional_cv nacional_N nacional_Npop nacional_deff `name1'

;
#delimit cr

}


putexcel A2=mat(final`iden', names) using "tabulados", modify sheet("`iden'", replace)
mat drop _all

restore
}

*==============================================================================*
*                            Tablas de doble entrada    					   *
*==============================================================================*

local ind = "i_sanea i_higiene i_agua agua_cp2"
foreach id of local ind {
  tabout etnia_jefe ninst_jefe quintil tipviv hacina `id' using `id'_unidad.txt, c(row) f(4c) replace svy
}

